@@ -5,6 +5,7 @@ assets2 = "https://github.com/kamangir/assets2/blob/main/bluer-robin"
 items = ImageItems(
     {
         f"{assets2}/20250712_114819.jpg": "",
+        "../../../diagrams/bluer_robin/wiring.png": "../../../diagrams/bluer_robin/wiring.svg",
         f"{assets2}/20250713_172325.jpg": "",
         f"{assets2}/20250713_172413.jpg": "",
         f"{assets2}/20250713_172442_1.gif": "",
@@ -14,5 +15,6 @@ items = ImageItems(
         f"{assets2}/20250726_134024.jpg": "",
         f"{assets2}/20250807_103534.jpg": "",
         f"{assets2}/20250807_171354.jpg": "",
+        f"{assets2}/20250813_172023.jpg": "",
     }
 )
