@@ -1,6 +1,12 @@
 from RPi import GPIO  # type: ignore
 
-from bluer_ugv.swallow.session.classical.camera import ClassicalCamera
+from bluer_sbc.env import BLUER_SBC_ENV
+
+from bluer_ugv.swallow.session.classical.camera import (
+    ClassicalCamera,
+    ClassicalNavigationCamera,
+    ClassicalTrackingCamera,
+)
 from bluer_ugv.swallow.session.classical.push_button import ClassicalPushButton
 from bluer_ugv.swallow.session.classical.keyboard import ClassicalKeyboard
 from bluer_ugv.swallow.session.classical.leds import ClassicalLeds
@@ -49,7 +55,17 @@ class ClassicalSession:
             leds=self.leds,
         )
 
-        self.camera = ClassicalCamera(
+        camera_class = (
+            ClassicalTrackingCamera
+            if BLUER_SBC_ENV == "tracking"
+            else (
+                ClassicalNavigationCamera
+                if BLUER_SBC_ENV == "navigation"
+                else ClassicalCamera
+            )
+        )
+        logger.info(f"camera: {camera_class.__name__}")
+        self.camera = camera_class(
             keyboard=self.keyboard,
             leds=self.leds,
             setpoint=self.setpoint,
